( cd usr/lib64 ; rm -rf libXvMC.so.1 )
( cd usr/lib64 ; ln -sf libXvMC.so.1.0.0 libXvMC.so.1 )
( cd usr/lib64 ; rm -rf libXvMC.so )
( cd usr/lib64 ; ln -sf libXvMC.so.1.0.0 libXvMC.so )
( cd usr/lib64 ; rm -rf libXvMCW.so.1 )
( cd usr/lib64 ; ln -sf libXvMCW.so.1.0.0 libXvMCW.so.1 )
( cd usr/lib64 ; rm -rf libXvMCW.so )
( cd usr/lib64 ; ln -sf libXvMCW.so.1.0.0 libXvMCW.so )
